document.addEventListener('DOMContentLoaded', () => {
  // Mobile menu functionality
  const mobileMenu = document.querySelector('.mobile-menu');
  const navLinks = document.querySelector('.nav-links');
  
  mobileMenu.addEventListener('click', () => {
    mobileMenu.classList.toggle('active');
    navLinks.classList.toggle('active');
  });

  // Smooth scroll for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      const target = document.querySelector(this.getAttribute('href'));
      
      window.scrollTo({
        top: target.offsetTop - 80,
        behavior: 'smooth'
      });
      
      // Close mobile menu if open
      mobileMenu.classList.remove('active');
      navLinks.classList.remove('active');
    });
  });

  // Form submission
  const contactForm = document.getElementById('contact-form');
  
  contactForm.addEventListener('submit', (e) => {
    e.preventDefault();
    
    // Add animation to button
    const submitButton = contactForm.querySelector('.submit-button');
    submitButton.style.opacity = '0.7';
    submitButton.textContent = 'Sending...';
    
    // Simulate form submission
    setTimeout(() => {
      submitButton.style.opacity = '1';
      submitButton.textContent = 'Message Sent!';
      contactForm.reset();
      
      setTimeout(() => {
        submitButton.textContent = 'Send Message';
      }, 2000);
    }, 1500);
  });

  // Intersection Observer for fade-in animations
  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.style.opacity = '1';
        entry.target.style.transform = 'translateY(0)';
      }
    });
  }, { threshold: 0.1 });

  document.querySelectorAll('.service-card, .feature').forEach(el => {
    el.style.opacity = '0';
    el.style.transform = 'translateY(20px)';
    el.style.transition = 'all 0.6s ease-out';
    observer.observe(el);
  });
});